Custom HTML widget creation function based on widget YAML and JavaScript for use in any html-compatible context
canvasXpress(
data = NULL,
smpAnnot = NULL,
varAnnot = NULL,
graphType = "Scatter2D",
events = NULL,
afterRender = NULL,
pretty = FALSE,
digits = 4,
width = 600,
height = 400,
destroy = FALSE,
...
)htmlwidgets object
data.frame-, matrix-, list- , or ggplot- classed object
additional data that applies to samples (columns)
additional data that applies to variables (rows)
type of graph to be plotted - default = "Scatter2D"
user-defined events (e.g. mousemove, mouseout, click and dblclick)
event triggered after rendering
print tagged code (JSON/HTML) nicely - default = FALSE
display digits - default = 4
plot width (valid CSS units) - default = 600px
plot height (valid CSS units) - default = 400px
used to indicate removal of a plot - default = FALSE
additional parameters passed to canvasXpress
Piping is supported (both the magrittr ' canvasXpress object into data parameter. Any new parameters will be added to the original configuration of the object, any parameters with data that existed before will be replaced, and any parameters set to null will be removed. It is important to note that primary data changes are not allowed in this construct - which means that anything specified by using the data, varAnnot, or smpAnnot parameters cannot be changed from the original values.